Pipelines
=========

This module contains pipeline implementations for different molecular structure prediction tasks.

AF3 Pipeline
------------

.. automodule:: atomworks.ml.pipelines.af3
   :members:
   :undoc-members:
   :show-inheritance:

RF2AA Pipeline
--------------

.. automodule:: atomworks.ml.pipelines.rf2aa
   :members:
   :undoc-members:
   :show-inheritance: 